==> jc-1.4.0.tar.gz: soot/dava/internal/AST/ASTControlFlowNode.h <==
// public abstract class soot.dava.internal.AST.ASTControlFlowNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class a1cb59fbdd01f4af soot_dava_internal_AST_ASTControlFlowNode
// @dep_class cab1e395a09c5dd8 soot_dava_internal_AST_ASTLabeledNode
// @dep_class 76430e9a28f2113d soot_dava_internal_AST_ASTNode
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_dava_internal_AST_ASTLabeledNode

#include "soot/dava/internal/AST/ASTLabeledNode.h"

#ifndef _JC_soot_dava_internal_AST_ASTControlFlowNode_H_
#define _JC_soot_dava_internal_AST_ASTControlFlowNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_ValueBox$object;
struct _jc_soot_dava_internal_SET_SETNodeLabel$object;
struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object;
struct _jc_soot_jimple_ConditionExpr$object;

// Typedefs
typedef struct _jc_soot_dava_internal_AST_ASTControlFlowNode$sub_refs	_jc_soot_dava_internal_AST_ASTControlFlowNode$sub_refs;
typedef struct _jc_soot_dava_internal_AST_ASTControlFlowNode$sub_nonrefs	_jc_soot_dava_internal_AST_ASTControlFlowNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTControlFlowNode$refs	_jc_soot_dava_internal_AST_ASTControlFlowNode$refs;
typedef struct _jc_soot_dava_internal_AST_ASTControlFlowNode$nonrefs	_jc_soot_dava_internal_AST_ASTControlFlowNode$nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTControlFlowNode$object	_jc_soot_dava_internal_AST_ASTControlFlowNode$object;

typedef const struct _jc_soot_dava_internal_AST_ASTControlFlowNode$vmethods	_jc_soot_dava_internal_AST_ASTControlFlowNode$vmethods;
typedef const struct _jc_soot_dava_internal_AST_ASTControlFlowNode$vtable	_jc_soot_dava_internal_AST_ASTControlFlowNode$vtable;
typedef const struct _jc_soot_dava_internal_AST_ASTControlFlowNode$vtype	_jc_soot_dava_internal_AST_ASTControlFlowNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_AST_ASTControlFlowNode$method$_init$ca469a7ffd764b05(_jc_env *, struct _jc_soot_dava_internal_AST_ASTControlFlowNode$object *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_soot_dava_internal_AST_ASTControlFlowNode$method$get__5fCondition$1ea493c48c17470a(_jc_env *, struct _jc_soot_dava_internal_AST_ASTControlFlowNode$object *);
extern void _jc_soot_dava_internal_AST_ASTControlFlowNode$method$perform__5fAnalysis$22b39eae4f6a8345(_jc_env *, struct _jc_soot_dava_internal_AST_ASTControlFlowNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_AST_ASTControlFlowNode$method_info$get__5fCondition$1ea493c48c17470a;
extern _jc_method _jc_soot_dava_internal_AST_ASTControlFlowNode$method_info$perform__5fAnalysis$22b39eae4f6a8345;

// Virtual methods structure
struct _jc_soot_dava_internal_AST_ASTControlFlowNode$vmethods {
	struct _jc_object	*(*get__5fCondition$1ea493c48c17470a)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTControlFlowNode$object *);
	void	(*perform__5fAnalysis$22b39eae4f6a8345)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTControlFlowNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *);
};

// Vtable
struct _jc_soot_dava_internal_AST_ASTControlFlowNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_dava_internal_AST_ASTNode$vmethods	soot_dava_internal_AST_ASTNode;
	_jc_soot_dava_internal_AST_ASTLabeledNode$vmethods	soot_dava_internal_AST_ASTLabeledNode;
	_jc_soot_dava_internal_AST_ASTControlFlowNode$vmethods	soot_dava_internal_AST_ASTControlFlowNode;
};

// Vtype
struct _jc_soot_dava_internal_AST_ASTControlFlowNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_AST_ASTControlFlowNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTControlFlowNode$sub_refs {
	struct _jc_object	*conditionBox;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTControlFlowNode$refs {
    _jc_soot_dava_internal_AST_ASTControlFlowNode$sub_refs	soot_dava_internal_AST_ASTControlFlowNode;
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_refs	soot_dava_internal_AST_ASTLabeledNode;
    _jc_soot_dava_internal_AST_ASTNode$sub_refs	soot_dava_internal_AST_ASTNode;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTControlFlowNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTControlFlowNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_dava_internal_AST_ASTNode$sub_nonrefs	soot_dava_internal_AST_ASTNode;
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_nonrefs	soot_dava_internal_AST_ASTLabeledNode;
    _jc_soot_dava_internal_AST_ASTControlFlowNode$sub_nonrefs	soot_dava_internal_AST_ASTControlFlowNode;
};

// Object instance structure
struct _jc_soot_dava_internal_AST_ASTControlFlowNode$object {
	_jc_soot_dava_internal_AST_ASTControlFlowNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_AST_ASTControlFlowNode$vtype	*vtype;
	_jc_soot_dava_internal_AST_ASTControlFlowNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_AST_ASTControlFlowNode$vtype _jc_soot_dava_internal_AST_ASTControlFlowNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_AST_ASTControlFlowNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_AST_ASTControlFlowNode$class_object;

#endif	/* _JC_soot_dava_internal_AST_ASTControlFlowNode_H_ */

==> jc-1.4.6.tar.gz: soot/dava/internal/AST/ASTControlFlowNode.h <==
// public abstract class soot.dava.internal.AST.ASTControlFlowNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class a1cb59fbdd01f4af soot_dava_internal_AST_ASTControlFlowNode
// @dep_class cab1e395a09c5dd8 soot_dava_internal_AST_ASTLabeledNode
// @dep_class 76430e9a28f2113d soot_dava_internal_AST_ASTNode
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_dava_internal_AST_ASTLabeledNode

#include "soot/dava/internal/AST/ASTLabeledNode.h"

#ifndef _JC_soot_dava_internal_AST_ASTControlFlowNode_H_
#define _JC_soot_dava_internal_AST_ASTControlFlowNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_ValueBox$object;
struct _jc_soot_dava_internal_SET_SETNodeLabel$object;
struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object;
struct _jc_soot_jimple_ConditionExpr$object;

// Typedefs
typedef struct _jc_soot_dava_internal_AST_ASTControlFlowNode$sub_refs	_jc_soot_dava_internal_AST_ASTControlFlowNode$sub_refs;
typedef struct _jc_soot_dava_internal_AST_ASTControlFlowNode$sub_nonrefs	_jc_soot_dava_internal_AST_ASTControlFlowNode$sub_nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTControlFlowNode$refs	_jc_soot_dava_internal_AST_ASTControlFlowNode$refs;
typedef struct _jc_soot_dava_internal_AST_ASTControlFlowNode$nonrefs	_jc_soot_dava_internal_AST_ASTControlFlowNode$nonrefs;
typedef struct _jc_soot_dava_internal_AST_ASTControlFlowNode$object	_jc_soot_dava_internal_AST_ASTControlFlowNode$object;

typedef const struct _jc_soot_dava_internal_AST_ASTControlFlowNode$vmethods	_jc_soot_dava_internal_AST_ASTControlFlowNode$vmethods;
typedef const struct _jc_soot_dava_internal_AST_ASTControlFlowNode$vtable	_jc_soot_dava_internal_AST_ASTControlFlowNode$vtable;
typedef const struct _jc_soot_dava_internal_AST_ASTControlFlowNode$vtype	_jc_soot_dava_internal_AST_ASTControlFlowNode$vtype;

// Constructors
extern void _jc_soot_dava_internal_AST_ASTControlFlowNode$method$_init$ca469a7ffd764b05(_jc_env *, struct _jc_soot_dava_internal_AST_ASTControlFlowNode$object *, struct _jc_soot_dava_internal_SET_SETNodeLabel$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_dava_internal_AST_ASTControlFlowNode$method$get__5fCondition$1ea493c48c17470a(_jc_env *, struct _jc_soot_dava_internal_AST_ASTControlFlowNode$object *) _JC_JCNI_ATTR;
extern void _jc_soot_dava_internal_AST_ASTControlFlowNode$method$perform__5fAnalysis$22b39eae4f6a8345(_jc_env *, struct _jc_soot_dava_internal_AST_ASTControlFlowNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_dava_internal_AST_ASTControlFlowNode$method_info$get__5fCondition$1ea493c48c17470a;
extern _jc_method _jc_soot_dava_internal_AST_ASTControlFlowNode$method_info$perform__5fAnalysis$22b39eae4f6a8345;

// Virtual methods structure
struct _jc_soot_dava_internal_AST_ASTControlFlowNode$vmethods {
	struct _jc_object	*(*get__5fCondition$1ea493c48c17470a)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTControlFlowNode$object *) _JC_JCNI_ATTR;
	void	(*perform__5fAnalysis$22b39eae4f6a8345)(_jc_env *, struct _jc_soot_dava_internal_AST_ASTControlFlowNode$object *, struct _jc_soot_dava_toolkits_base_AST_ASTAnalysis$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_dava_internal_AST_ASTControlFlowNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_dava_internal_AST_ASTNode$vmethods	soot_dava_internal_AST_ASTNode;
	_jc_soot_dava_internal_AST_ASTLabeledNode$vmethods	soot_dava_internal_AST_ASTLabeledNode;
	_jc_soot_dava_internal_AST_ASTControlFlowNode$vmethods	soot_dava_internal_AST_ASTControlFlowNode;
};

// Vtype
struct _jc_soot_dava_internal_AST_ASTControlFlowNode$vtype {
	_jc_type			type;
	_jc_soot_dava_internal_AST_ASTControlFlowNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTControlFlowNode$sub_refs {
	struct _jc_object	*conditionBox;
};

// Reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTControlFlowNode$refs {
    _jc_soot_dava_internal_AST_ASTControlFlowNode$sub_refs	soot_dava_internal_AST_ASTControlFlowNode;
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_refs	soot_dava_internal_AST_ASTLabeledNode;
    _jc_soot_dava_internal_AST_ASTNode$sub_refs	soot_dava_internal_AST_ASTNode;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_dava_internal_AST_ASTControlFlowNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_dava_internal_AST_ASTControlFlowNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_dava_internal_AST_ASTNode$sub_nonrefs	soot_dava_internal_AST_ASTNode;
    _jc_soot_dava_internal_AST_ASTLabeledNode$sub_nonrefs	soot_dava_internal_AST_ASTLabeledNode;
    _jc_soot_dava_internal_AST_ASTControlFlowNode$sub_nonrefs	soot_dava_internal_AST_ASTControlFlowNode;
};

// Object instance structure
struct _jc_soot_dava_internal_AST_ASTControlFlowNode$object {
	_jc_soot_dava_internal_AST_ASTControlFlowNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_dava_internal_AST_ASTControlFlowNode$vtype	*vtype;
	_jc_soot_dava_internal_AST_ASTControlFlowNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_dava_internal_AST_ASTControlFlowNode$vtype _jc_soot_dava_internal_AST_ASTControlFlowNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_dava_internal_AST_ASTControlFlowNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_dava_internal_AST_ASTControlFlowNode$class_object;

#endif	/* _JC_soot_dava_internal_AST_ASTControlFlowNode_H_ */
